@@ -29,7 +29,7 @@ fullnameseparator="" #default ''
 fullname="false" #default false
 failfast="false" #defult false
 maxrerun=3 #default 3
-rerun="true" #default false
+rerun="false" #default false
 importtype="junit" #default junit
 reporttype="directory" #default directory other option file, when directory needs to end with /
 teststorun="all" #options include - high, medium, low, unassigned, ready, open, none
@@ -677,7 +677,7 @@ def runtestswithappsurify(*args):
     fullname="false" #default false
     failfast="false" #defult false
     maxrerun=3 #default 3
-    rerun="true" #default false
+    rerun="false" #default false
     importtype="junit" #default junit
     reporttype="directory" #default directory other option file, when directory needs to end with /
     teststorun="all" #options include - high, medium, low, unassigned, ready, open, none
@@ -1315,10 +1315,14 @@ def runtestswithappsurify(*args):
         print(("testsrun1 = " + testsrun))
         testsrun = get_and_run_tests(i) + testsrun
 
+    print("Tests to run")
     print(testsrun)
 
-    os.environ["TESTSTORUN"] = testsrun
-
+    try:
+        os.environ["TESTSTORUN"] = testsrun
+    except: # catch *all* exceptions
+      e = sys.exc_info()[0]
+      print( "Error: %s" % e )
     
 
     if testsrun == "":
@@ -1326,8 +1330,8 @@ def runtestswithappsurify(*args):
             execute_tests("", 0)
             os.environ["TESTSTORUN"] = "*"
 
-    print("tests " + os.environ.get('TESTSTORUN'))
-    print("##vso[task.setvariable variable=TestsToRun;isOutput=true]"+testsrun)
+    #print("tests " + os.environ.get('TESTSTORUN'))
+    #print("##vso[task.setvariable variable=TestsToRun;isOutput=true]"+testsrun)
 
 
     if failfast == "false" and rerun == "true" and teststorun != "none":
@@ -1336,7 +1340,7 @@ def runtestswithappsurify(*args):
     getresults()
 
 def main(*argv):
-    print(argv)
+    #print(argv)
     runtestswithappsurify(argv)
   
 main(sys.argv)
\ No newline at end of file
